@@ -1,8 +1,11 @@
+from __future__ import absolute_import
 import re
-import os, threading, collections
+import os
+import threading
+import collections
 from functools import wraps
-from flask import Module, make_response, url_for, render_template, request, session, redirect, g, current_app
-from decorators import login_required, with_lock
+from flask import Blueprint, make_response, url_for, render_template, request, session, redirect, g, current_app
+from .decorators import login_required, with_lock
 from collections import defaultdict
 from werkzeug.utils import secure_filename
 from flask.ext.babel import Babel, gettext, ngettext, lazy_gettext
@@ -11,7 +14,7 @@ _ = gettext
 from sagenb.notebook.interact import INTERACT_UPDATE_PREFIX
 from sagenb.notebook.misc import encode_response
 
-ws = Module('sagenb.flask_version.worksheet')
+ws = Blueprint('worksheet', 'sagenb.flask_version.worksheet')
 worksheet_locks = defaultdict(threading.Lock)
 
 def worksheet_view(f):
@@ -42,7 +45,7 @@ def worksheet_view(f):
                 worksheet.set_active(g.username)
 
             #This was in twist.Worksheet.childFactory
-            from base import notebook_updates
+            from .base import notebook_updates
             notebook_updates()
 
             return f(username, id, **kwds)
@@ -382,7 +385,7 @@ def worksheet_eval(worksheet):
     documentation of the function and the source code of the function
     respectively.
     """
-    from base import notebook_updates
+    from .base import notebook_updates
 
     r = {}
 
@@ -478,7 +481,7 @@ def worksheet_cell_update(worksheet):
 
     if 'Unhandled SIGSEGV' in cell.output_text(raw=True).split('\n'):
         r['interrupted'] = 'restart'
-        print 'Segmentation fault detected in output!'
+        print('Segmentation fault detected in output!')
 
 
     r['output'] = cell.output_text(html=True) + ' '
