@@ -24,7 +24,12 @@ AUTHORS:
 
 """
 
-import os, random, re, urllib2, urllib
+import os
+import random
+import re
+
+from six.moves.urllib.parse import urlencode
+from six.moves.urllib.request import urlopen, Request
 
 from sagenb.notebook.template import template
 from flask.ext.babel import gettext, lazy_gettext
@@ -527,14 +532,14 @@ class reCAPTCHAChallenge(AbstractChallenge):
                 return s.encode('utf-8')
             return s
 
-        params = urllib.urlencode({
+        params = urlencode({
                 'privatekey': encode_if_necessary(self.private_key),
                 'remoteip' :  encode_if_necessary(self.remote_ip),
                 'challenge':  encode_if_necessary(challenge_field),
                 'response' :  encode_if_necessary(response_field)
                 })
 
-        request = urllib2.Request(
+        request = Request(
             url = "http://%s/verify" % RECAPTCHA_VERIFY_SERVER,
             data = params,
             headers = {
@@ -543,7 +548,7 @@ class reCAPTCHAChallenge(AbstractChallenge):
                 }
             )
 
-        httpresp = urllib2.urlopen(request)
+        httpresp = urlopen(request)
         return_values = httpresp.read().splitlines();
         httpresp.close();
         return_code = return_values[0]
