@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*
 import os
 
-from notebook_object import notebook
+from .notebook_object import notebook
 
 def sagetex(filename, gen=True, **kwds):
     """
@@ -15,12 +15,12 @@ def sagetex(filename, gen=True, **kwds):
         [pops up web browser with live version of foo.tex.]
     """
     if not os.path.exists(filename):
-        raise IOError, "No such file: '%s'"%filename
+        raise IOError("No such file: '%s'" % filename)
 
     if not filename.endswith('.tex'):
-        raise ValueError, "File must be a latex file (end in .tex): '%s'"%filename
+        raise ValueError("File must be a latex file (end in .tex): '%s'" % filename)
     if not '\\document' in open(filename).read():
-        raise ValueError, "File must be a latex file (contain \\document...): '%s'"%filename
+        raise ValueError("File must be a latex file (contain \\document...): '%s'" % filename)
     
     if gen:
         os.system('latex2html -no_images %s'%filename)
