@@ -37,11 +37,18 @@ Sage notebook server::
              
 """
 
-import copy, cPickle, shutil, tarfile, tempfile
-
+import copy
+import shutil
+import tarfile
+import tempfile
 import os
+try:
+   import cPickle as pickle
+except ImportError:
+   import pickle
+from six import iteritems
 
-from abstract_storage import Datastore
+from .abstract_storage import Datastore
 from sagenb.misc.misc import set_restrictive_permissions, encoded_str
 
 from sage.misc.temporary_file import atomic_write
@@ -90,7 +97,11 @@ class FilesystemDatastore(Datastore):
     #########################################################################
     def _makepath(self, path):
         p = self._abspath(path)
-        if not os.path.exists(p): os.makedirs(p)
+        try:
+            os.makedirs(p)
+        except OSError:
+            if not os.path.isdir(p):
+                raise
         return path
     
     def _deep_user_path(self, username):
@@ -105,22 +116,29 @@ class FilesystemDatastore(Datastore):
         # There are weird cases, e.g., old notebook server migration
         # where username is None, and if we don't string it here,
         # saving can be broken (at a bad moment!).
-        
         # There are also some cases where the username could have unicode in it.
         username = str(username)
-        path = self._abspath(os.path.join(self._home_path, username))
+
+        home = self._abspath(self._home_path)
+        path = os.path.join(home, username)
         if not os.path.islink(path):
-            if not os.path.exists(path):
-                self._makepath(path)
+            self._makepath(home)
 
             old_dir = os.getcwd()
-            os.chdir(self._abspath(self._home_path))
+            os.chdir(home)
             new_path = self._deep_user_path(username)
 
-            #Move the directory to the __store__ directory
-            os.rename(path, new_path)
+            # Ensure that new_path exists:
+            if os.path.exists(path):
+                # If the old path exists, move it to the new path.
+                # If both the old and new path exist, that's an error
+                # and this will raise an exception.
+                os.rename(path, new_path)
+            else:
+                # Otherwise, simply create the new path.
+                self._makepath(os.path.join(home, new_path))
 
-            #new_path now points to the actual directory
+            # new_path now points to the actual directory
             os.symlink(new_path, username)
             os.chdir(old_dir)
 
@@ -166,7 +184,7 @@ class FilesystemDatastore(Datastore):
     #########################################################################
     def _load(self, filename):
         with open(self._abspath(filename)) as f:
-            result = cPickle.load(f)
+            result = pickle.load(f)
         return result
 
     def _save(self, obj, filename):
@@ -176,7 +194,7 @@ class FilesystemDatastore(Datastore):
         Check that interrupting ``_save`` is safe::
 
             sage: from sagenb.storage.filesystem_storage import FilesystemDatastore
-            sage: D = FilesystemDatastore("")
+            sage: D = FilesystemDatastore(tmp_dir())
             sage: fn = tmp_filename()
             sage: s = "X" * 100000
             sage: D._save(s, fn)
@@ -184,14 +202,17 @@ class FilesystemDatastore(Datastore):
             ....:     alarm(1)
             ....:     while True:
             ....:         D._save(s, fn)
-            ....: except (AlarmInterrupt, OSError):
+            ....: except (AlarmInterrupt, OSError, AttributeError):
             ....:     # OSError could happen due to a double close() in
             ....:     # Python's tempfile module.
+            ....:     # AttributeError could happen due to interrupting
+            ....:     # in _TemporaryFileWrapper.__init__
+            ....:     # (see https://trac.sagemath.org/ticket/22423)
             ....:     pass
             sage: len(D._load(fn))
             100000
         """
-        s = cPickle.dumps(obj)
+        s = pickle.dumps(obj)
         if len(s) == 0:
             raise ValueError("Invalid Pickle")
         with atomic_write(self._abspath(filename)) as f:
@@ -211,7 +232,7 @@ class FilesystemDatastore(Datastore):
         return dict([(name, User_from_basic(basic)) for name, basic in obj])
 
     def _users_to_basic(self, users):
-        new = list(sorted([[name, U.basic()] for name, U in users.iteritems()]))
+        new = sorted([[name, U.basic()] for name, U in iteritems(users)])
         return new
 
     def _basic_to_server_conf(self, obj):
@@ -441,12 +462,12 @@ class FilesystemDatastore(Datastore):
         except Exception:
             #the worksheet conf loading didn't work, so we make up one
             import traceback
-            print "Warning: problem loading config for %s/%s; using default config: %s"%(username, id_number, traceback.format_exc())
+            print("Warning: problem loading config for %s/%s; using default config: %s" % (username, id_number, traceback.format_exc()))
             W = self._basic_to_worksheet({'owner':username, 'id_number': id_number})
             if username=='_sage_':
                 # save the default configuration, since this may be loaded by a random other user
                 # since *anyone* looking at docs will load all _sage_ worksheets
-                print "Saving default configuration (overwriting corrupt configuration) for %s/%s"%(username, id_number)
+                print("Saving default configuration (overwriting corrupt configuration) for %s/%s" % (username, id_number))
                 self.save_worksheet(W, conf_only=True)
         return W
 
@@ -471,7 +492,7 @@ class FilesystemDatastore(Datastore):
         # Remove metainformation that perhaps shouldn't be distributed
         for k in ['owner', 'ratings', 'worksheet_that_was_published', 'viewers', 'tags', 'published_id_number',
                   'collaborators', 'auto_publish']:
-            if basic.has_key(k):
+            if k in basic:
                 del basic[k]
                 
         self._save(basic, self._worksheet_conf_filename(username, id_number) + '2')
@@ -523,7 +544,7 @@ class FilesystemDatastore(Datastore):
         T = tarfile.open(filename, 'r:bz2')
         members = [a for a in T.getmembers() if 'worksheet.txt' in a.name and is_safe(a.name)]
         if len(members) == 0:
-            raise RuntimeError, "unable to import worksheet"
+            raise RuntimeError("unable to import worksheet")
 
         worksheet_txt = members[0].name
         W = self.load_worksheet(username, id_number)
@@ -629,7 +650,7 @@ class FilesystemDatastore(Datastore):
                     v.append(self.load_worksheet(username, int(id_number)))
                 except Exception:
                     import traceback
-                    print "Warning: problem loading %s/%s: %s"%(username, id_number, traceback.format_exc())
+                    print("Warning: problem loading %s/%s: %s" % (username, id_number, traceback.format_exc()))
         return v
 
     def readonly_user(self, username):
@@ -651,7 +672,6 @@ class FilesystemDatastore(Datastore):
         Delete all files associated with this datastore.  Dangerous!
         This is only here because it is useful for doctesting.
         """
-        import shutil
         shutil.rmtree(self._path, ignore_errors=True)
 
 
